==> ldap-account-manager_5.2.orig.tar.bz2: ldap-account-manager-5.2/templates/lib/extra/ckeditor/plugins/table/lang/de.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'de', {
	border: 'Rahmen',
	caption: 'Überschrift',
	cell: {
		menu: 'Zelle',
		insertBefore: 'Zelle davor einfügen',
		insertAfter: 'Zelle danach einfügen',
		deleteCell: 'Zelle löschen',
		merge: 'Zellen verbinden',
		mergeRight: 'Nach rechts verbinden',
		mergeDown: 'Nach unten verbinden',
		splitHorizontal: 'Zelle horizontal teilen',
		splitVertical: 'Zelle vertikal teilen',
		title: 'Zellen-Eigenschaften',
		cellType: 'Zellart',
		rowSpan: 'Anzahl Zeilen verbinden',
		colSpan: 'Anzahl Spalten verbinden',
		wordWrap: 'Zeilenumbruch',
		hAlign: 'Horizontale Ausrichtung',
		vAlign: 'Vertikale Ausrichtung',
		alignBaseline: 'Grundlinie',
		bgColor: 'Hintergrundfarbe',
		borderColor: 'Rahmenfarbe',
		data: 'Daten',
		header: 'Überschrift',
		yes: 'Ja',
		no: 'Nein',
		invalidWidth: 'Zellenbreite muß eine Zahl sein.',
		invalidHeight: 'Zellenhöhe muß eine Zahl sein.',
		invalidRowSpan: '"Anzahl Zeilen verbinden" muss eine Ganzzahl sein.',
		invalidColSpan: '"Anzahl Spalten verbinden" muss eine Ganzzahl sein.',
		chooseColor: 'Wählen'
	},
	cellPad: 'Zellenabstand innen',
	cellSpace: 'Zellenabstand außen',
	column: {
		menu: 'Spalte',
		insertBefore: 'Spalte links davor einfügen',
		insertAfter: 'Spalte rechts danach einfügen',
		deleteColumn: 'Spalte löschen'
	},
	columns: 'Spalte',
	deleteTable: 'Tabelle löschen',
	headers: 'Kopfzeile',
	headersBoth: 'Beide',
	headersColumn: 'Erste Spalte',
	headersNone: 'Keine',
	headersRow: 'Erste Zeile',
	invalidBorder: 'Die Rahmenbreite muß eine Zahl sein.',
	invalidCellPadding: 'Der Zellenabstand innen muß eine positive Zahl sein.',
	invalidCellSpacing: 'Der Zellenabstand außen muß eine positive Zahl sein.',
	invalidCols: 'Die Anzahl der Spalten muß größer als 0 sein..',
	invalidHeight: 'Die Tabellenbreite muß eine Zahl sein.',
	invalidRows: 'Die Anzahl der Zeilen muß größer als 0 sein.',
	invalidWidth: 'Die Tabellenbreite muss eine Zahl sein.',
	menu: 'Tabellen-Eigenschaften',
	row: {
		menu: 'Zeile',
		insertBefore: 'Zeile oberhalb einfügen',
		insertAfter: 'Zeile unterhalb einfügen',
		deleteRow: 'Zeile entfernen'
	},
	rows: 'Zeile',
	summary: 'Inhaltsübersicht',
	title: 'Tabellen-Eigenschaften',
	toolbar: 'Tabelle',
	widthPc: '%',
	widthPx: 'Pixel',
	widthUnit: 'Breite Einheit'
} );

==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/table/lang/de.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'de', {
	border: 'Rahmengröße',
	caption: 'Überschrift',
	cell: {
		menu: 'Zelle',
		insertBefore: 'Zelle davor einfügen',
		insertAfter: 'Zelle danach einfügen',
		deleteCell: 'Zelle löschen',
		merge: 'Zellen verbinden',
		mergeRight: 'Nach rechts verbinden',
		mergeDown: 'Nach unten verbinden',
		splitHorizontal: 'Zelle horizontal teilen',
		splitVertical: 'Zelle vertikal teilen',
		title: 'Zelleneigenschaften',
		cellType: 'Zellart',
		rowSpan: 'Anzahl Zeilen verbinden',
		colSpan: 'Anzahl Spalten verbinden',
		wordWrap: 'Zeilenumbruch',
		hAlign: 'Horizontale Ausrichtung',
		vAlign: 'Vertikale Ausrichtung',
		alignBaseline: 'Grundlinie',
		bgColor: 'Hintergrundfarbe',
		borderColor: 'Rahmenfarbe',
		data: 'Daten',
		header: 'Überschrift',
		yes: 'Ja',
		no: 'Nein',
		invalidWidth: 'Zellenbreite muss eine Zahl sein.',
		invalidHeight: 'Zellenhöhe muss eine Zahl sein.',
		invalidRowSpan: '"Anzahl Zeilen verbinden" muss eine Ganzzahl sein.',
		invalidColSpan: '"Anzahl Spalten verbinden" muss eine Ganzzahl sein.',
		chooseColor: 'Wählen'
	},
	cellPad: 'Zellenabstand innen',
	cellSpace: 'Zellenabstand außen',
	column: {
		menu: 'Spalte',
		insertBefore: 'Spalte links davor einfügen',
		insertAfter: 'Spalte rechts danach einfügen',
		deleteColumn: 'Spalte löschen'
	},
	columns: 'Spalte',
	deleteTable: 'Tabelle löschen',
	headers: 'Kopfzeile',
	headersBoth: 'Beide',
	headersColumn: 'Erste Spalte',
	headersNone: 'Keine',
	headersRow: 'Erste Zeile',
	invalidBorder: 'Die Rahmenbreite muß eine Zahl sein.',
	invalidCellPadding: 'Der Zellenabstand innen muß eine positive Zahl sein.',
	invalidCellSpacing: 'Der Zellenabstand außen muß eine positive Zahl sein.',
	invalidCols: 'Die Anzahl der Spalten muß größer als 0 sein..',
	invalidHeight: 'Die Tabellenbreite muß eine Zahl sein.',
	invalidRows: 'Die Anzahl der Zeilen muß größer als 0 sein.',
	invalidWidth: 'Die Tabellenbreite muss eine Zahl sein.',
	menu: 'Tabellen-Eigenschaften',
	row: {
		menu: 'Zeile',
		insertBefore: 'Zeile oberhalb einfügen',
		insertAfter: 'Zeile unterhalb einfügen',
		deleteRow: 'Zeile entfernen'
	},
	rows: 'Zeile',
	summary: 'Inhaltsübersicht',
	title: 'Tabellen-Eigenschaften',
	toolbar: 'Tabelle',
	widthPc: '%',
	widthPx: 'Pixel',
	widthUnit: 'Breite Einheit'
} );
